package com.oqpo.api.service.inoutmng;


import com.oqpo.api.entity.inoutmng.*;
import com.oqpo.api.entity.loanmng.LoanMgntBaseInfoEntity;
import com.oqpo.api.entity.oper.FileEntity;
import com.oqpo.api.entity.pomng.PchOdrBaseInfoEntity;
import com.oqpo.api.entity.pomng.PchOdrDtlPtclEntity;
import com.oqpo.api.entity.rtnmng.RtnOdrBaseInfoEntity;
import com.oqpo.api.entity.rtnmng.RtnOdrDtlPtclEntity;
import com.oqpo.api.entity.stinfo.BrandEntity;
import com.oqpo.api.entity.stinfo.SpplyEntity;
import com.oqpo.api.entity.stinfo.StoreBaseInfoEntity;
import com.oqpo.api.entity.stockmng.StckMgntBaseInfoEntity;
import com.oqpo.api.entity.stockmng.StckMgntDtlHistEntity;
import com.oqpo.api.entity.stockmng.WhsProcInfoPtclEntity;
import com.oqpo.api.enums.ChgDvsn;
import com.oqpo.api.enums.InOutCd;
import com.oqpo.api.enums.SystemMessageCode;
import com.oqpo.api.exception.GlobalException;
import com.oqpo.api.mapper.FileMapper;
import com.oqpo.api.mapper.inoutmng.ColOdrMapper;
import com.oqpo.api.mapper.inoutmng.ShmtOdrMapper;
import com.oqpo.api.mapper.loanmng.LoanStateMapper;
import com.oqpo.api.mapper.pomng.PchOrdMapper;
import com.oqpo.api.mapper.rtnmng.RtnOdrMapper;
import com.oqpo.api.mapper.stinfo.BrandMapper;
import com.oqpo.api.mapper.stinfo.StoreBaseInfoMapper;
import com.oqpo.api.mapper.stinfo.SupplyMapper;
import com.oqpo.api.mapper.stockmng.StockMngMapper;
import com.oqpo.api.service.CommonService;
import com.oqpo.api.service.pomng.PchOrdService;
import com.oqpo.api.service.rtnmng.RtnOdrService;
import com.oqpo.api.web.dto.request.GridRequest;
import com.oqpo.api.web.dto.request.inoutmng.InstColOdrRequest;
import com.oqpo.api.web.dto.request.inoutmng.InstShmtOdrRequest;
import com.oqpo.api.web.dto.request.inoutmng.SaveSpplyDlvRequest;
import com.oqpo.api.web.dto.request.inoutmng.SaveWarehouseProcRequest;
import com.oqpo.api.web.dto.response.GridResponse;
import com.oqpo.api.web.dto.response.inoutmng.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Service
@Slf4j
public class ColOdrService extends CommonService {
    @Autowired
    private ColOdrMapper colOdrMapper;

    @Autowired
    private RtnOdrMapper rtnOdrMapper;

    @Autowired
    private RtnOdrService rtnOdrService;


    @Autowired
    private BrandMapper brandMapper;

    @Autowired
    private SupplyMapper supplyMapper;

    @Autowired
    private StoreBaseInfoMapper storeBaseInfoMapper;

    @Autowired
    private LoanStateMapper loanStateMapper;

    @Autowired
    private FileMapper fileMapper;

    /*
      수거 대상 그리드 리스트 조회
     */
    public GridResponse selectShmtTargetOdrGridList(String sBrandId, String fromDt, String toDt, String sWhsId, String sRtnWhsId, String sItemNm, GridRequest gridRequest) throws Exception {
        int gridPage = gridRequest.getGridPage();
        int gridSize = gridRequest.getGridSize();

        fromDt = fromDt == null ? null : fromDt.replace(".", "");
        toDt = toDt == null ? null : toDt.replace(".", "");

        int gridRecords = colOdrMapper.selectColTargetRtnGridCnt(sBrandId, fromDt, toDt, sWhsId, sRtnWhsId, sItemNm);
        int gridTotal = fnCalculateGridTotal(gridSize, gridRecords);
        List<RtnOdrBaseInfoEntity> entities = colOdrMapper.selectColTargetRtnGridList(sBrandId, fromDt, toDt, sWhsId,sRtnWhsId, sItemNm, gridRequest);
        List<Object> gridRows = entities.stream()
                .map(m -> ColTragetOdrSearchListResponse.builder()
                        .viewCd("R")
                        .brandId(m.getBrandId() == null ? "" : m.getBrandId())
                        .brandNm(m.getBrandNm() == null ? "" : m.getBrandNm())
                        .rtnPodrUnqNo(m.getRtnPodrUnqNo() == null ? "" : m.getRtnPodrUnqNo())
                        .rtnPodrDtlNo(m.getRtnOdrDtlInfo() == null ? "" : m.getRtnOdrDtlInfo().getRtnPodrDtlNo() == null ? "" : m.getRtnOdrDtlInfo().getRtnPodrDtlNo())
                        .rtnReqUnqNo(m.getRtnOdrDtlInfo() == null ? "" : m.getRtnOdrDtlInfo().getRtnReqUnqNo() == null ? "" : m.getRtnOdrDtlInfo().getRtnReqUnqNo())
                        .rtnReqDtlNo(m.getRtnOdrDtlInfo() == null ? "" : m.getRtnOdrDtlInfo().getRtnReqDtlNo() == null ? "" : m.getRtnOdrDtlInfo().getRtnReqDtlNo())
                        .itemId(m.getRtnOdrDtlInfo() == null ? "" : m.getRtnOdrDtlInfo().getItemId() == null ? "" : m.getRtnOdrDtlInfo().getItemId())
                        .itemNm(m.getRtnOdrDtlInfo() == null ? "" : m.getRtnOdrDtlInfo().getItemNm() == null ? "" : m.getRtnOdrDtlInfo().getItemNm())
                        .rtnWhsId(m.getRtnWhsId() == null ? "" : m.getRtnWhsId())
                        .rtnLocation(m.getRtnLocation() == null ? "" : m.getRtnLocation())
                        .rntWhsNm(m.getRtnWhsNm() == null ? "" : m.getRtnWhsNm())
                        .whsId(m.getWhsId() == null ? "" : m.getWhsId())
                        .location(m.getLocation() == null ? "" : m.getLocation())
                        .whsNm(m.getWhsNm() == null ? "" : m.getWhsNm())
                        .unitAmt(m.getRtnOdrDtlInfo() == null ? 0 : m.getRtnOdrDtlInfo().getUnitAmt() == null ? 0 : m.getRtnOdrDtlInfo().getUnitAmt())
                        .rtnReqQty(m.getRtnOdrDtlInfo() == null ? 0 : m.getRtnOdrDtlInfo().getRtnReqQty() == null ? 0 : m.getRtnOdrDtlInfo().getRtnReqQty())
                        .rtnQty(m.getRtnOdrDtlInfo() == null ? 0 : m.getRtnOdrDtlInfo().getRtnQty() == null ? 0 : m.getRtnOdrDtlInfo().getRtnQty())
                        .rtnAmt(m.getRtnOdrDtlInfo() == null ? 0 : m.getRtnOdrDtlInfo().getRtnAmt() == null ? 0 : m.getRtnOdrDtlInfo().getRtnAmt())
                        .colReqDt(m.getColReqDt() == null ? "" : m.getColReqDt())
                        .storeId(m.getStoreId() == null ? "" : m.getStoreId())
                        .build())
                .collect(Collectors.toList());
        return GridResponse.toDTO(gridPage, gridTotal, gridRecords, gridRows);
    }

    /*
      수거지시 저장
*/
    @Transactional
    public void instColOdr(String userId, InstColOdrRequest instColOdrRequest) throws Exception {
        try {

            List<RtnOdrDtlPtclEntity> gridInsertData = instColOdrRequest.toCodeEntities(instColOdrRequest.getGridInsertData());


            List<RtnOdrBaseInfoEntity> jobList = colOdrMapper.selectPickJobDataList(instColOdrRequest.getBrandId(), gridInsertData);

            String whsId = "";
            String location = "";
            String rtnWhsId = "";
            String rtnLocation = "";
            int itemQty = 0;
            long colTotalAmt = 0;
            int colQty = 0;
            String colCmdUnqNo = "";
            String colPickUnqNo = "";

            ColOdrBaseEntity colOdrBaseEntity = new ColOdrBaseEntity();
            List<ColOdrDtlPtclEntity> colDtlList = new ArrayList<ColOdrDtlPtclEntity>();

            PickInfoMgntEntity pickInfoMgntEntity = new PickInfoMgntEntity();
            List<PickDtlPtclEntity> pickDtlList = new ArrayList<PickDtlPtclEntity>();

            for (int i = 0; i < jobList.size(); i++) {
                RtnOdrBaseInfoEntity entity = jobList.get(i);

                for (int j = 0; j < gridInsertData.size(); j++) {
                    RtnOdrDtlPtclEntity reqEntity = gridInsertData.get(j);

                    if (entity.getRtnPodrUnqNo().equals(reqEntity.getRtnPodrUnqNo()) && entity.getRtnOdrDtlInfo().getRtnPodrDtlNo().equals(reqEntity.getRtnPodrDtlNo())) {
                        if (reqEntity.getColQty() > entity.getRtnOdrDtlInfo().getRtnOdrQty()) {
                            // 발주수량보다 수거수량이 많을수 없습니다.
                            throw new GlobalException(SystemMessageCode.ERR_POPICKQTY);
                        }

                        colQty = reqEntity.getColQty();

                        break;
                    }
                }

                if (rtnWhsId.equals(entity.getRtnWhsId()) && rtnLocation.equals(entity.getRtnLocation()) && whsId.equals(entity.getWhsId()) && location.equals(entity.getLocation())) {
                    // 추가 작업
                    itemQty = itemQty + 1;
                    colTotalAmt = colTotalAmt + (entity.getRtnOdrDtlInfo().getUnitAmt() * colQty);
                    colOdrBaseEntity.setItemQty(itemQty);
                    colOdrBaseEntity.setColTotalAmt(colTotalAmt);
                    pickInfoMgntEntity.setColTotAmt(colTotalAmt);

                    //수거서 상세 정보
                    int dtlNo = itemQty * 10;

                    ColOdrDtlPtclEntity colDtlEntity = new ColOdrDtlPtclEntity();
                    colDtlEntity.setColCmdUnqNo(colCmdUnqNo);
                    colDtlEntity.setColCmdDtlNo(Integer.toString(dtlNo));
                    colDtlEntity.setItemId(entity.getRtnOdrDtlInfo().getItemId());
                    colDtlEntity.setItemNm(entity.getRtnOdrDtlInfo().getItemNm());
                    colDtlEntity.setUnitAmt(entity.getRtnOdrDtlInfo().getUnitAmt());
                    colDtlEntity.setColQty(colQty);
                    colDtlEntity.setColAmt(colQty * entity.getRtnOdrDtlInfo().getUnitAmt());
                    colDtlEntity.setRtnQty(entity.getRtnOdrDtlInfo().getRtnOdrQty());
                    colDtlEntity.setRtnAmt(entity.getRtnOdrDtlInfo().getRtnOdrAmt());
                    colDtlEntity.setRtnRsnDvsn(entity.getRtnOdrDtlInfo().getRtnRsnDvsn());
                    colDtlEntity.setRtnRsn(entity.getRtnOdrDtlInfo().getRtnRsn());
                    colDtlEntity.setRtnPodrUnqNo(entity.getRtnPodrUnqNo());
                    colDtlEntity.setRtnPodrDtlNo(entity.getRtnOdrDtlInfo().getRtnPodrDtlNo());
                    colDtlEntity.setRtnReqUnqNo(entity.getRtnOdrDtlInfo().getRtnReqUnqNo());
                    colDtlEntity.setRtnReqDtlNo(entity.getRtnOdrDtlInfo().getRtnReqDtlNo());

                    colDtlList.add(colDtlEntity);

                    PickDtlPtclEntity pickDtlEntity = new PickDtlPtclEntity();
                    pickDtlEntity.setColPickUnqNo(colPickUnqNo);

                    pickDtlEntity.setColPickDtlNo(Integer.toString(dtlNo));
                    pickDtlEntity.setRtnPodrUnqNo(entity.getRtnPodrUnqNo());
                    pickDtlEntity.setRtnPodrDtlNo(entity.getRtnOdrDtlInfo().getRtnPodrDtlNo());
                    pickDtlEntity.setRtnReqUnqNo(entity.getRtnOdrDtlInfo().getRtnReqUnqNo());
                    pickDtlEntity.setRtnReqDtlNo(entity.getRtnOdrDtlInfo().getRtnReqDtlNo());
                    pickDtlEntity.setColCmdUnqNo(colCmdUnqNo);
                    pickDtlEntity.setColCmdDtlNo(Integer.toString(dtlNo));
                    pickDtlEntity.setItemId(entity.getRtnOdrDtlInfo().getItemId());
                    pickDtlEntity.setItemNm(entity.getRtnOdrDtlInfo().getItemNm());
                    pickDtlEntity.setUnit(entity.getRtnOdrDtlInfo().getUnit());
                    pickDtlEntity.setUnitAmt(entity.getRtnOdrDtlInfo().getUnitAmt());
                    pickDtlEntity.setRodrQty(entity.getRtnOdrDtlInfo().getRtnOdrQty());
                    pickDtlEntity.setColQty(colQty);
                    pickDtlEntity.setColAmt(colQty * entity.getRtnOdrDtlInfo().getUnitAmt());

                    pickDtlList.add(pickDtlEntity);

                } else {
                    // 신규로 출하건 생성함  //select fn_get_dealno(16, '') as col_cmd_unq_no
                    if (colDtlList.size() > 0) {

                        colOdrMapper.insertColOdrBase(userId,colOdrBaseEntity);
                        colOdrMapper.insertColOdrDtl(userId,colDtlList);
                        colOdrMapper.insertPickMgntBase(userId,pickInfoMgntEntity);
                        colOdrMapper.insertPickDtlPtcl(userId,pickDtlList);

                        itemQty = 0;
                        colTotalAmt = 0;
                    }
                    itemQty = 1;
                    colTotalAmt = entity.getRtnOdrDtlInfo().getUnitAmt() * colQty;

                    whsId = entity.getWhsId();
                    location = entity.getLocation();
                    rtnWhsId = entity.getRtnWhsId();
                    rtnLocation = entity.getRtnLocation();

                    colCmdUnqNo = fnGetDealNo(20, "");  // 출하지시번호
                    colPickUnqNo = fnGetDealNo(15, ""); // 납품서번호

                    // 수거지시
                    colOdrBaseEntity = new ColOdrBaseEntity();
                    colDtlList = new ArrayList<ColOdrDtlPtclEntity>();
                    ColOdrDtlPtclEntity colDtlEntity = new ColOdrDtlPtclEntity();

                    //납품서정보
                    pickInfoMgntEntity = new PickInfoMgntEntity();
                    pickDtlList = new ArrayList<PickDtlPtclEntity>();
                    PickDtlPtclEntity pickDtlEntity = new PickDtlPtclEntity();

                    colOdrBaseEntity.setColCmdUnqNo(colCmdUnqNo);
                    colOdrBaseEntity.setBrandId(entity.getBrandId());
                    colOdrBaseEntity.setWhsId(entity.getWhsId());
                    colOdrBaseEntity.setLocation(entity.getLocation());
                    colOdrBaseEntity.setStoreId(entity.getStoreId());
                    //colOdrBaseEntity.setItemQty(itemQty);
                    //colOdrBaseEntity.setColTotalAmt(colTotalAmt);
                    colOdrBaseEntity.setColReqDt(instColOdrRequest.getColSchDt().replaceAll("//.",""));
                    colOdrBaseEntity.setColDvsn("C001");
                    colOdrBaseEntity.setColCmdStCd("COL1");
                    colOdrBaseEntity.setColReqMgrNm(entity.getRtnMgrNm());
                    colOdrBaseEntity.setColReqMgrId(entity.getRtnMgrId());
                    colOdrBaseEntity.setColDt(null);
                    colOdrBaseEntity.setColCnfmNm(null);
                    colOdrBaseEntity.setColCnfmId(null);
                    colOdrBaseEntity.setColMgrNm(instColOdrRequest.getPickMgrNm());
                    colOdrBaseEntity.setColMgrTelNo(instColOdrRequest.getPickMgrTelNo());
                    colOdrBaseEntity.setColMgrEmal(null);
                    colOdrBaseEntity.setColMgrMblNo(null);
                    colOdrBaseEntity.setRtnWhsId(entity.getRtnWhsId());
                    colOdrBaseEntity.setRtnLocation(entity.getRtnLocation());
                    colOdrBaseEntity.setSpplyId(entity.getSpplyId());
                    colOdrBaseEntity.setSpplyNm(entity.getSpplyNm());

                    colDtlEntity.setColCmdUnqNo(colCmdUnqNo);
                    colDtlEntity.setColCmdDtlNo("10");
                    colDtlEntity.setItemId(entity.getRtnOdrDtlInfo().getItemId());
                    colDtlEntity.setItemNm(entity.getRtnOdrDtlInfo().getItemNm());
                    colDtlEntity.setUnitAmt(entity.getRtnOdrDtlInfo().getUnitAmt());
                    colDtlEntity.setColQty(colQty);
                    colDtlEntity.setColAmt(colQty * entity.getRtnOdrDtlInfo().getUnitAmt());
                    colDtlEntity.setRtnQty(entity.getRtnOdrDtlInfo().getRtnOdrQty());
                    colDtlEntity.setRtnAmt(entity.getRtnOdrDtlInfo().getRtnOdrAmt());
                    colDtlEntity.setRtnRsnDvsn(entity.getRtnOdrDtlInfo().getRtnRsnDvsn());
                    colDtlEntity.setRtnRsn(entity.getRtnOdrDtlInfo().getRtnRsn());
                    colDtlEntity.setRtnPodrUnqNo(entity.getRtnPodrUnqNo());
                    colDtlEntity.setRtnPodrDtlNo(entity.getRtnOdrDtlInfo().getRtnPodrDtlNo());
                    colDtlEntity.setRtnReqUnqNo(entity.getRtnOdrDtlInfo().getRtnReqUnqNo());
                    colDtlEntity.setRtnReqDtlNo(entity.getRtnOdrDtlInfo().getRtnReqDtlNo());

                    pickDtlEntity.setColPickUnqNo(colPickUnqNo);

                    pickDtlEntity.setColPickDtlNo("10");
                    pickDtlEntity.setRtnPodrUnqNo(entity.getRtnPodrUnqNo());
                    pickDtlEntity.setRtnPodrDtlNo(entity.getRtnOdrDtlInfo().getRtnPodrDtlNo());
                    pickDtlEntity.setRtnReqUnqNo(entity.getRtnOdrDtlInfo().getRtnReqUnqNo());
                    pickDtlEntity.setRtnReqDtlNo(entity.getRtnOdrDtlInfo().getRtnReqDtlNo());
                    pickDtlEntity.setColCmdUnqNo(colCmdUnqNo);
                    pickDtlEntity.setColCmdDtlNo("10");
                    pickDtlEntity.setItemId(entity.getRtnOdrDtlInfo().getItemId());
                    pickDtlEntity.setItemNm(entity.getRtnOdrDtlInfo().getItemNm());
                    pickDtlEntity.setUnit(entity.getRtnOdrDtlInfo().getUnit());
                    pickDtlEntity.setUnitAmt(entity.getRtnOdrDtlInfo().getUnitAmt());
                    pickDtlEntity.setRodrQty(entity.getRtnOdrDtlInfo().getRtnOdrQty());
                    pickDtlEntity.setColQty(colQty);
                    pickDtlEntity.setColAmt(colQty * entity.getRtnOdrDtlInfo().getUnitAmt());

                    pickDtlList.add(pickDtlEntity);
                }

                // 마지막 부분일 경우 
                if (i == jobList.size() - 1) {
                    if (colDtlList.size() > 0) {
                        colOdrMapper.insertColOdrBase(userId,colOdrBaseEntity);
                        colOdrMapper.insertColOdrDtl(userId,colDtlList);
                        colOdrMapper.insertPickMgntBase(userId,pickInfoMgntEntity);
                        colOdrMapper.insertPickDtlPtcl(userId,pickDtlList);
                    }
                }

                // 수거상태 변경처리
                // 1. 수거상세정보 상태 없데이트 한후  pchOrdMapper

                for (int poi = 0; poi < gridInsertData.size(); poi++) {
                    gridInsertData.get(poi).setRodrDtlStCd("ROD3");
                }
                rtnOdrMapper.updateChangeMultiRodrDtlStCd(userId, gridInsertData);

                // 반품발주 헤더 상태 처리  updateChgMultiPodrStCd
                String rtnPodrUnqNo = "";
                for (int k = 0; k < gridInsertData.size(); k++) {
                    if (!rtnPodrUnqNo.equals(gridInsertData.get(k).getRtnPodrUnqNo())) {
                        rtnPodrUnqNo = gridInsertData.get(k).getRtnPodrUnqNo();
                        String rtnOdrStCd = rtnOdrService.selectRtnOdrDtlStatusList(rtnPodrUnqNo);
                        rtnOdrMapper.updateChgRodrStCd(userId, rtnPodrUnqNo, rtnOdrStCd);
                    }
                }
            }


        } catch (GlobalException e) {
            //e.getStackTrace();
            e.printStackTrace();
            throw new GlobalException(e.getSystemMessageCode());
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }

    /* 출하현황
    public GridResponse selectShmtSearchGridList(String sBrandId, String fromDt, String toDt, String sShmtWhsId, String sShmtReqStCd, String sWhsId, String sItemNm, GridRequest gridRequest) throws Exception {
        int gridPage = gridRequest.getGridPage();
        int gridSize = gridRequest.getGridSize();

        fromDt = fromDt == null ? null : fromDt.replace(".", "");
        toDt = toDt == null ? null : toDt.replace(".", "");

        int gridRecords = shmtOdrMapper.selectShmtSearchGridCnt(sBrandId, fromDt, toDt, sShmtWhsId, sShmtReqStCd, sWhsId, sItemNm);
        int gridTotal = fnCalculateGridTotal(gridSize, gridRecords);
        List<ShmtOdrBaseEntity> entities = shmtOdrMapper.selectShmtSearchGridList(sBrandId, fromDt, toDt, sShmtWhsId, sShmtReqStCd, sWhsId, sItemNm, gridRequest);
        List<Object> gridRows = entities.stream()
                .map(m -> ShmtOutSearchListResponse.builder()
                        .viewCd("R")
                        .shmtReqUnqNo(m.getShmtReqUnqNo() == null ? "" : m.getShmtReqUnqNo())
                        .shmtReqDtlNo(m.getShmtOdrDtlInfo() == null ? "" : m.getShmtOdrDtlInfo().getShmtReqDtlNo() == null ? "" : m.getShmtOdrDtlInfo().getShmtReqDtlNo())
                        .brandId(m.getBrandId() == null ? "" : m.getBrandId())
                        .brandNm(m.getBrandNm() == null ? "" : m.getBrandNm())
                        .pchPodrUnqNo(m.getShmtOdrDtlInfo() == null ? "" : m.getShmtOdrDtlInfo().getPchPodrUnqNo() == null ? "" : m.getShmtOdrDtlInfo().getPchPodrUnqNo())
                        .pchPodrDtlNo(m.getShmtOdrDtlInfo() == null ? "" : m.getShmtOdrDtlInfo().getPchPodrDtlNo() == null ? "" : m.getShmtOdrDtlInfo().getPchPodrDtlNo())
                        .shmtReqStCd(m.getShmtReqStCd() == null ? "" : m.getShmtReqStCd())
                        .shmtReqStNm(m.getShmtReqStNm() == null ? "" : m.getShmtReqStNm())
                        .itemId(m.getShmtOdrDtlInfo() == null ? "" : m.getShmtOdrDtlInfo().getItemId() == null ? "" : m.getShmtOdrDtlInfo().getItemId())
                        .itemNm(m.getShmtOdrDtlInfo() == null ? "" : m.getShmtOdrDtlInfo().getItemNm() == null ? "" : m.getShmtOdrDtlInfo().getItemNm())
                        .whsId(m.getWhsId() == null ? "" : m.getWhsId())
                        .whsNm(m.getWhsNm() == null ? "" : m.getWhsNm() + " - " + m.getLocationNm())
                        .location(m.getLocation() == null ? "" : m.getLocation())
                        .shmtQty(m.getShmtOdrDtlInfo() == null ? 0 : m.getShmtOdrDtlInfo().getShmtQty() == null ? 0 : m.getShmtOdrDtlInfo().getShmtQty())
                        .shmtAmt(m.getShmtOdrDtlInfo() == null ? 0 : m.getShmtOdrDtlInfo().getShmtAmt() == null ? 0 : m.getShmtOdrDtlInfo().getShmtAmt())
                        .whsQty(m.getWhsProcInfo() == null ? 0 : m.getWhsProcInfo().getWhsQty() == null ? 0 : m.getWhsProcInfo().getWhsQty())
                        .whsAmt(m.getWhsProcInfo() == null ? 0 : m.getWhsProcInfo().getWhsAmt() == null ? 0 : m.getWhsProcInfo().getWhsAmt())
                        .whsDt(m.getWhsProcInfo() == null ? "" : m.getWhsProcInfo().getWhsDt() == null ? "" : m.getWhsProcInfo().getWhsDt())
                        .whsCnfmNm(m.getWhsProcInfo() == null ? "" : m.getWhsProcInfo().getWhsCnfmNm() == null ? "" : m.getWhsProcInfo().getWhsCnfmNm())
                        .dlvSttmtUnqNo(m.getDlvSttmtUnqNo() == null ? "" : m.getDlvSttmtUnqNo())
                        .build())
                .collect(Collectors.toList());
        return GridResponse.toDTO(gridPage, gridTotal, gridRecords, gridRows);
    }
*/
    /* 납품서 정보
    public InvInfoResponse selectInvInfo(String brandId, String dlvSttmtUnqNo) throws Exception {

        DeliInfoMgntEntity entity = shmtOdrMapper.selectInvInfo(brandId, dlvSttmtUnqNo);
        List<DeliDtlMgntEntity> dtlEntity = shmtOdrMapper.selectInvDtlList(brandId, dlvSttmtUnqNo);


        // 공급사
        // 배송처 정보
        BrandEntity brandEntity = brandMapper.selectBrandInfo(brandId);

        if ("DL01".equals(entity.getDeliDvsn())) {
            //브랜드정보 배송
            entity.setDlvBsnsRegno(brandEntity.getBsnsRegNo());
            entity.setDlvNm(brandEntity.getBrandNm());
            entity.setDlvOwnerNm(brandEntity.getOwnerNm());
            entity.setDlvAddr(brandEntity.getAddr1() + " " + brandEntity.getAddr2());

        } else {
            //공급사 배송
            SpplyEntity dlv_spplyEntity = supplyMapper.selectSpplyInfo(brandId, entity.getSpplyId());
            entity.setDlvBsnsRegno(dlv_spplyEntity.getBsnsRegNo());
            entity.setDlvNm(dlv_spplyEntity.getSpplyNm());
            entity.setDlvOwnerNm(dlv_spplyEntity.getOwnerNm());
            entity.setDlvAddr(dlv_spplyEntity.getAddr1() + " " + dlv_spplyEntity.getAddr2());
        }


        //발주처 정보
        if ("W01".equals(entity.getWhsDvsn())) {
            //납품창고 본사
            entity.setPoBsnsRegno(brandEntity.getBsnsRegNo());
            entity.setPoNm(brandEntity.getBrandNm());
            entity.setPoOwnerNm(brandEntity.getOwnerNm());
            entity.setPoAddr(brandEntity.getAddr1() + " " + brandEntity.getAddr2());
        } else {
            //납품창고 매장
            StoreBaseInfoEntity whs_storeBaseInfoEntity = storeBaseInfoMapper.selectStoreInfo(brandId, entity.getStoreId());
            entity.setPoBsnsRegno(whs_storeBaseInfoEntity.getBsnsRegNo());
            entity.setPoNm(whs_storeBaseInfoEntity.getStoreNm());
            entity.setPoOwnerNm(whs_storeBaseInfoEntity.getOwnerNm());
            entity.setPoAddr(whs_storeBaseInfoEntity.getAddr1() + " " + whs_storeBaseInfoEntity.getAddr2());
        }

        // 브랜드 로고 brand_logo_file_no
        List<FileEntity> logFileList = null;
        if (!"".equals(brandEntity.getBrandLogoFileNo())) {
            logFileList = fileMapper.selectFileList(brandEntity.getBrandLogoFileNo());
        } else {
            logFileList = new ArrayList<FileEntity>();
        }

        return InvInfoResponse.toDTO(entity, dtlEntity, logFileList);
    }

*/
    /*
     출하 대상 그리드 리스트 조회

    public GridResponse selectSpplyTargetOdrGridList(String sBrandId, String fromDt, String toDt, String sSpplyId, String sWhsId, String sItemNm, GridRequest gridRequest) throws Exception {
        int gridPage = gridRequest.getGridPage();
        int gridSize = gridRequest.getGridSize();

        fromDt = fromDt == null ? null : fromDt.replace(".", "");
        toDt = toDt == null ? null : toDt.replace(".", "");

        int gridRecords = shmtOdrMapper.selectSpplyTargetOdrGridCnt(sBrandId, fromDt, toDt, sSpplyId, sWhsId, sItemNm);
        int gridTotal = fnCalculateGridTotal(gridSize, gridRecords);
        List<PchOdrBaseInfoEntity> entities = shmtOdrMapper.selectSpplyTargetOdrGridList(sBrandId, fromDt, toDt, sSpplyId, sWhsId, sItemNm, gridRequest);
        List<Object> gridRows = entities.stream()
                .map(m -> SpplyTargerOdrSearchListResponse.builder()
                        .viewCd("R")
                        .brandId(m.getBrandId() == null ? "" : m.getBrandId())
                        .brandNm(m.getBrandNm() == null ? "" : m.getBrandNm())
                        .pchPodrUnqNo(m.getPchPodrUnqNo() == null ? "" : m.getPchPodrUnqNo())
                        .pchPodrDtlNo(m.getPchOdrDtlInfo() == null ? "" : m.getPchOdrDtlInfo().getPchPodrDtlNo() == null ? "" : m.getPchOdrDtlInfo().getPchPodrDtlNo())
                        .itemId(m.getPchOdrDtlInfo() == null ? "" : m.getPchOdrDtlInfo().getItemId() == null ? "" : m.getPchOdrDtlInfo().getItemId())
                        .itemNm(m.getPchOdrDtlInfo() == null ? "" : m.getPchOdrDtlInfo().getItemNm() == null ? "" : m.getPchOdrDtlInfo().getItemNm())
                        .whsId(m.getWhsId() == null ? "" : m.getWhsId())
                        .whsNm(m.getWhsNm() == null ? "" : m.getWhsNm() + " - " + m.getLocationNm())
                        .location(m.getLocation() == null ? "" : m.getLocation())
                        .unitAmt(m.getPchOdrDtlInfo() == null ? 0 : m.getPchOdrDtlInfo().getUnitAmt() == null ? 0 : m.getPchOdrDtlInfo().getUnitAmt())
                        .podrQty(m.getPchOdrDtlInfo() == null ? 0 : m.getPchOdrDtlInfo().getPodrQty() == null ? 0 : m.getPchOdrDtlInfo().getPodrQty())
                        .podrAmt(m.getPchOdrDtlInfo() == null ? 0 : m.getPchOdrDtlInfo().getPodrAmt() == null ? 0 : m.getPchOdrDtlInfo().getPodrAmt())
                        .dlvReqDt(m.getDlvReqDt() == null ? "" : m.getDlvReqDt())
                        .build())
                .collect(Collectors.toList());
        return GridResponse.toDTO(gridPage, gridTotal, gridRecords, gridRows);
    }
*/

    /* 공급사 납품서 생성 초기 정보
    public SpplyInvInitResponse selectSpplyShmtOdrInfo(String brandId, String spplyId, String pchPodrUnqNo) throws Exception {
        PchOdrBaseInfoEntity entity = shmtOdrMapper.selectSpplyShmtOdrInfo(brandId, spplyId, pchPodrUnqNo);
        List<PchOdrDtlPtclEntity> dtlEntity = shmtOdrMapper.selectSpplyShmtOdrList(pchPodrUnqNo);

        return SpplyInvInitResponse.toDTO(entity, dtlEntity);
    }
*/
    /* 공급사 납품서 생성 저장
    @Transactional
    public void saveSpplyInv(String userId, SaveSpplyDlvRequest saveSpplyDlvRequest) throws Exception {
        try {

            List<PchOdrDtlPtclEntity> gridInsertData = saveSpplyDlvRequest.toCodeEntities(saveSpplyDlvRequest.getGridInsertData());
            List<PchOdrBaseInfoEntity> jobList = shmtOdrMapper.selectShmtJobDataList(saveSpplyDlvRequest.getBrandId(), gridInsertData);
            long shmtTotalAmt = 0;
            String expryDate = "";
            int shmtQty = 0;
            String dlvSttmtUnqNo = "";
            String storeId = "" ;
            long chgLoanAmt = 0 ;

            DeliInfoMgntEntity deliBaseEntity = new DeliInfoMgntEntity();
            List<DeliDtlMgntEntity> deliDtlList = new ArrayList<DeliDtlMgntEntity>();


            for (int i = 0; i < jobList.size(); i++) {
                PchOdrBaseInfoEntity entity = jobList.get(i);



                for (int j = 0; j < gridInsertData.size(); j++) {
                    PchOdrDtlPtclEntity reqEntity = gridInsertData.get(j);
                    if (entity.getPchPodrUnqNo().equals(reqEntity.getPchPodrUnqNo()) && entity.getPchOdrDtlInfo().getPchPodrDtlNo().equals(reqEntity.getPchPodrDtlNo())) {
                        if (reqEntity.getShmtQty() > entity.getPchOdrDtlInfo().getPodrQty()) {
                            // 발주수량보다 출고수량이 많을수 없습니다.
                            throw new GlobalException(SystemMessageCode.ERR_POSHNONQTY);
                        }

                        if ("Y".equals(entity.getPchOdrDtlInfo().getExpryYn())) {
                            if (reqEntity.getExpryDate() == null || "".equals(reqEntity.getExpryDate())) {
                                // 유통기한을 입력해주세요!
                                throw new GlobalException(SystemMessageCode.ERR_NONEXPRY);
                            }
                        }

                        // 동일 납품처가 아니면 오류 처리
                        if (!"".equals(storeId) && !storeId.equals(entity.getStoreId())) {
                            throw new GlobalException(SystemMessageCode.ERR_NEQWHSID);
                        }

                        if (reqEntity.getShmtQty() < entity.getPchOdrDtlInfo().getPodrQty()) {

                            chgLoanAmt = chgLoanAmt + (entity.getPchOdrDtlInfo().getPodrQty() - reqEntity.getShmtQty()) * entity.getPchOdrDtlInfo().getUnitAmt();
                        }

                        expryDate = reqEntity.getExpryDate().replaceAll("\\.", "");
                        shmtQty = reqEntity.getShmtQty();

                        break;
                    }
                }

                shmtTotalAmt = shmtTotalAmt + (entity.getPchOdrDtlInfo().getUnitAmt() * shmtQty);
                if (i == 0 ) {
                    dlvSttmtUnqNo = fnGetDealNo(15, ""); // 납품서번호
                    deliBaseEntity.setDlvSttmtUnqNo(dlvSttmtUnqNo);
                    deliBaseEntity.setDlvSttmtUnqNo(dlvSttmtUnqNo);
                    deliBaseEntity.setSpplyId(entity.getSpplyId());
                    deliBaseEntity.setSpplyNm(entity.getSpplyNm());
                    deliBaseEntity.setStoreId(entity.getStoreId());
                    //deliBaseEntity.setDlvAmt(shmtTotalAmt);
                    deliBaseEntity.setDlvMgrNm(saveSpplyDlvRequest.getDlvMgrNm());
                    deliBaseEntity.setDlvMgrTelNo(saveSpplyDlvRequest.getDlvMgrTelNo().replaceAll("-", ""));
                    deliBaseEntity.setDlvMgrEmal(null);
                    deliBaseEntity.setDlvMgrMblNo(null);
                    deliBaseEntity.setVndrTelNo(entity.getDeliTelNo().replaceAll("-", ""));
                    deliBaseEntity.setDlvStCd("DLV0");
                    deliBaseEntity.setPodrRegDt(entity.getPodrDt());
                    deliBaseEntity.setDlvReqDt(entity.getDlvReqDt().replaceAll("\\.", ""));
                    deliBaseEntity.setDlvSchDt(saveSpplyDlvRequest.getDlvSchDt().replaceAll("\\.", ""));
                    deliBaseEntity.setDlvCmpltDt(null);
                    deliBaseEntity.setWhsId(entity.getWhsId());
                    deliBaseEntity.setLocation(entity.getLocation());
                    if ("".equals(entity.getStoreId()) || entity.getStoreId() == null) {
                        deliBaseEntity.setWhsDvsn("W01");
                    } else {
                        deliBaseEntity.setWhsDvsn("W02");
                    }
                    deliBaseEntity.setBrandId(saveSpplyDlvRequest.getBrandId());
                }

                int dtlNo = (i+1) * 10;

                DeliDtlMgntEntity inaddDeliDtlEntity = new DeliDtlMgntEntity();
                inaddDeliDtlEntity.setDlvSttmtUnqNo(dlvSttmtUnqNo);
                inaddDeliDtlEntity.setDlvSttmtDtlNo(Integer.toString(dtlNo));
                inaddDeliDtlEntity.setPchPodrUnqNo(entity.getPchPodrUnqNo());
                inaddDeliDtlEntity.setPchPodrDtlNo(entity.getPchOdrDtlInfo().getPchPodrDtlNo());
                inaddDeliDtlEntity.setPchReqUnqNo(entity.getPchOdrDtlInfo().getPchReqUnqNo());
                inaddDeliDtlEntity.setPchReqDtlNo(entity.getPchOdrDtlInfo().getPchReqDtlNo());
                inaddDeliDtlEntity.setItemId(entity.getPchOdrDtlInfo().getItemId());
                inaddDeliDtlEntity.setItemNm(entity.getPchOdrDtlInfo().getItemNm());
                inaddDeliDtlEntity.setUnit(entity.getPchOdrDtlInfo().getUnit());
                inaddDeliDtlEntity.setUnitAmt(entity.getPchOdrDtlInfo().getUnitAmt());
                inaddDeliDtlEntity.setPodrQty(entity.getPchOdrDtlInfo().getPodrQty());
                inaddDeliDtlEntity.setDlvQty(shmtQty);
                inaddDeliDtlEntity.setPodrAmt(entity.getPchOdrDtlInfo().getPodrAmt());
                inaddDeliDtlEntity.setDlvAmt(shmtQty * entity.getPchOdrDtlInfo().getUnitAmt());
                inaddDeliDtlEntity.setExpryDate(expryDate);

                deliDtlList.add(inaddDeliDtlEntity);

            }

            deliBaseEntity.setDlvAmt(shmtTotalAmt);
            shmtOdrMapper.insertDeliInfoMngt(userId, deliBaseEntity);
            shmtOdrMapper.insertDeliDtlPtcl(userId, deliDtlList);

            // 변동금액 시 여신수정
            if (chgLoanAmt > 0 ) {
                String loanMgntUnqNo = storeBaseInfoMapper.selectStoreLoanMgntUnqNo(storeId);
                loanStateMapper.updateloanMinusInstProc(loanMgntUnqNo, storeId, chgLoanAmt);
            }


            for (int poi = 0; poi < gridInsertData.size(); poi++) {
                gridInsertData.get(poi).setPodrDtlStCd("POD3");
            }
            pchOrdMapper.updateChangeStPodrDtl(userId, gridInsertData);

            // 발주 헤더 상태 처리  updateChgMultiPodrStCd
            String pchPodrUnqNo = "";
            for (int k = 0; k < gridInsertData.size(); k++) {
                if (!pchPodrUnqNo.equals(gridInsertData.get(k).getPchPodrUnqNo())) {
                    pchPodrUnqNo = gridInsertData.get(k).getPchPodrUnqNo();
                    String pchOdrStCd = pchOrdService.selectOdrDtlStatusList(pchPodrUnqNo);
                    pchOrdMapper.updateChgPodrStCd(userId, pchOdrStCd, pchPodrUnqNo);
                }
            }

        } catch (GlobalException e) {
            //e.getStackTrace();
            e.printStackTrace();
            throw new GlobalException(e.getSystemMessageCode());
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
*/

    /*
      납품서 현황 그리드 리스트 조회

    public GridResponse selectDeliGridList(String sBrandId, String dtGubun,  String fromDt, String toDt, String sDlvStCd, String sSpplyId, String sWhsId, String sItemNm, GridRequest gridRequest) throws Exception {
        int gridPage = gridRequest.getGridPage();
        int gridSize = gridRequest.getGridSize();

        fromDt = fromDt == null ? null : fromDt.replace(".", "");
        toDt = toDt == null ? null : toDt.replace(".", "");

        int gridRecords = shmtOdrMapper.selectDeliGridCnt(sBrandId, dtGubun, fromDt, toDt, sDlvStCd, sSpplyId, sWhsId, sItemNm);
        int gridTotal = fnCalculateGridTotal(gridSize, gridRecords);
        List<DeliInfoMgntEntity> entities = shmtOdrMapper.selectDeliGridList(sBrandId, dtGubun, fromDt, toDt, sDlvStCd, sSpplyId, sWhsId, sItemNm, gridRequest);
        List<Object> gridRows = entities.stream()
                .map(m -> DeliDtlSearchListResponse.builder()
                        .viewCd("R")
                        .brandId(m.getBrandId() == null ? "" : m.getBrandId())
                        .brandNm(m.getBrandNm() == null ? "" : m.getBrandNm())
                        .dlvSttmtUnqNo(m.getDlvSttmtUnqNo() == null ? "" : m.getDlvSttmtUnqNo())
                        .spplyId(m.getSpplyId() == null ? "" : m.getSpplyId())
                        .spplyNm(m.getSpplyNm() == null ? "" : m.getSpplyNm())
                        .dlvStCd(m.getDlvStCd() == null ? "" : m.getDlvStCd())
                        .dlvStNm(m.getDlvStNm() == null ? "" : m.getDlvStNm())
                        .whsId(m.getWhsId() == null ? "" :m.getWhsId())
                        .location(m.getLocation() == null ? "" : m.getLocation())
                        .whsNm(m.getWhsNm() == null ? "" : m.getWhsNm() + " - " + m.getLocationNm())
                        .podrRegDt(m.getPodrRegDt() == null ? "" : m.getPodrRegDt())
                        .dlvRegDt(m.getDlvRegDt() == null ? "" : m.getDlvRegDt())
                        .dlvReqDt(m.getDlvReqDt() == null ? "" : m.getDlvReqDt())
                        .dlvSchDt(m.getDlvSchDt() == null ? "" : m.getDlvSchDt())
                        .dlvCmpltDt(m.getDlvCmpltDt() == null ? "" : m.getDlvCmpltDt())
                        .itemId(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getItemId() == null ? "" : m.getDeliDtlMgntInfo().getItemId())
                        .itemNm(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getItemNm() == null ? "" : m.getDeliDtlMgntInfo().getItemNm())
                        .podrQty(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getPodrQty() == null ? 0 : m.getDeliDtlMgntInfo().getPodrQty())
                        .dlvQty(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getDlvQty() == null ? 0 : m.getDeliDtlMgntInfo().getDlvQty())
                        .unit(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getUnit() == null ? "" : m.getDeliDtlMgntInfo().getUnit())
                        .unitAmt(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getUnitAmt() == null ? 0 : m.getDeliDtlMgntInfo().getUnitAmt())
                        .dlvMgrNm(m.getDlvMgrNm() == null ? "" : m.getDlvMgrNm())
                        .dlvMgrTelNo(m.getDlvMgrTelNo() == null ? "" : m.getDlvMgrTelNo())
                        .build())
                .collect(Collectors.toList());
        return GridResponse.toDTO(gridPage, gridTotal, gridRecords, gridRows);
    }
*/

    /*
      공급사  - 납품서 현황 그리드 리스트 조회

    public GridResponse selectSpplyDeliGridList(String sBrandId, String fromDt, String toDt, String sSpplyId, String sWhsId, String sItemNm, GridRequest gridRequest) throws Exception {
        int gridPage = gridRequest.getGridPage();
        int gridSize = gridRequest.getGridSize();

        fromDt = fromDt == null ? null : fromDt.replace(".", "");
        toDt = toDt == null ? null : toDt.replace(".", "");

        int gridRecords = shmtOdrMapper.selectSpplyDeliGridCnt(sBrandId,  fromDt, toDt, sSpplyId, sWhsId, sItemNm);
        int gridTotal = fnCalculateGridTotal(gridSize, gridRecords);
        List<DeliInfoMgntEntity> entities = shmtOdrMapper.selectSpplyDeliGridList(sBrandId, fromDt, toDt, sSpplyId, sWhsId, sItemNm, gridRequest);
        List<Object> gridRows = entities.stream()
                .map(m -> DeliDtlSearchListResponse.builder()
                        .viewCd("R")
                        .brandId(m.getBrandId() == null ? "" : m.getBrandId())
                        .brandNm(m.getBrandNm() == null ? "" : m.getBrandNm())
                        .dlvSttmtUnqNo(m.getDlvSttmtUnqNo() == null ? "" : m.getDlvSttmtUnqNo())
                        .spplyId(m.getSpplyId() == null ? "" : m.getSpplyId())
                        .spplyNm(m.getSpplyNm() == null ? "" : m.getSpplyNm())
                        .dlvStCd(m.getDlvStCd() == null ? "" : m.getDlvStCd())
                        .dlvStNm(m.getDlvStNm() == null ? "" : m.getDlvStNm())
                        .whsId(m.getWhsId() == null ? "" :m.getWhsId())
                        .location(m.getLocation() == null ? "" : m.getLocation())
                        .whsNm(m.getWhsNm() == null ? "" : m.getWhsNm() + " - " + m.getLocationNm())
                        .podrRegDt(m.getPodrRegDt() == null ? "" : m.getPodrRegDt())
                        .dlvRegDt(m.getDlvRegDt() == null ? "" : m.getDlvRegDt())
                        .dlvReqDt(m.getDlvReqDt() == null ? "" : m.getDlvReqDt())
                        .dlvSchDt(m.getDlvSchDt() == null ? "" : m.getDlvSchDt())
                        .dlvCmpltDt(m.getDlvCmpltDt() == null ? "" : m.getDlvCmpltDt())
                        .itemId(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getItemId() == null ? "" : m.getDeliDtlMgntInfo().getItemId())
                        .itemNm(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getItemNm() == null ? "" : m.getDeliDtlMgntInfo().getItemNm())
                        .podrQty(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getPodrQty() == null ? 0 : m.getDeliDtlMgntInfo().getPodrQty())
                        .dlvQty(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getDlvQty() == null ? 0 : m.getDeliDtlMgntInfo().getDlvQty())
                        .unit(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getUnit() == null ? "" : m.getDeliDtlMgntInfo().getUnit())
                        .unitAmt(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getUnitAmt() == null ? 0 : m.getDeliDtlMgntInfo().getUnitAmt())
                        .dlvMgrNm(m.getDlvMgrNm() == null ? "" : m.getDlvMgrNm())
                        .dlvMgrTelNo(m.getDlvMgrTelNo() == null ? "" : m.getDlvMgrTelNo())
                        .build())
                .collect(Collectors.toList());
        return GridResponse.toDTO(gridPage, gridTotal, gridRecords, gridRows);
    }
 */
    /*
      입고처리 그리드 리스트 조회

    public GridResponse selectWarehouseTargetList(String sBrandId, String fromDt, String toDt, String sWhsId, String sSpplyId, String sDlvSttmtUnqNo, String sItemNm, GridRequest gridRequest) throws Exception {
        int gridPage = gridRequest.getGridPage();
        int gridSize = gridRequest.getGridSize();

        fromDt = fromDt == null ? null : fromDt.replace(".", "");
        toDt = toDt == null ? null : toDt.replace(".", "");

        int gridRecords = shmtOdrMapper.selectWarehouseTargetGridCnt(sBrandId,  fromDt, toDt, sWhsId, sSpplyId, sDlvSttmtUnqNo, sItemNm);
        int gridTotal = fnCalculateGridTotal(gridSize, gridRecords);
        List<DeliInfoMgntEntity> entities = shmtOdrMapper.selectWarehouseTargetGridList(sBrandId,  fromDt, toDt, sWhsId, sSpplyId, sDlvSttmtUnqNo, sItemNm, gridRequest);
        List<Object> gridRows = entities.stream()
                .map(m -> WarehouseTargetResponse.builder()
                        .viewCd("R")
                        .brandId(m.getBrandId() == null ? "" : m.getBrandId())
                        .brandNm(m.getBrandNm() == null ? "" : m.getBrandNm())
                        .dlvSttmtUnqNo(m.getDlvSttmtUnqNo() == null ? "" : m.getDlvSttmtUnqNo())
                        .dlvSttmtDtlNo(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getDlvSttmtDtlNo() == null ? "" : m.getDeliDtlMgntInfo().getDlvSttmtDtlNo())
                        .itemId(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getItemId() == null ? "" : m.getDeliDtlMgntInfo().getItemId())
                        .itemNm(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getItemNm() == null ? "" : m.getDeliDtlMgntInfo().getItemNm())
                        .podrQty(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getPodrQty() == null ? 0 : m.getDeliDtlMgntInfo().getPodrQty())
                        .dlvQty(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getDlvQty() == null ? 0 : m.getDeliDtlMgntInfo().getDlvQty())
                        .whsQty(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getWhsQty() == null ? 0 : m.getDeliDtlMgntInfo().getWhsQty())
                        .whsAmt(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getWhsAmt() == null ? 0 : m.getDeliDtlMgntInfo().getWhsAmt())
                        .unit(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getUnit() == null ? "" : m.getDeliDtlMgntInfo().getUnit())
                        .unitAmt(m.getDeliDtlMgntInfo() == null ? 0 : m.getDeliDtlMgntInfo().getUnitAmt() == null ? 0 : m.getDeliDtlMgntInfo().getUnitAmt())
                        .whsId(m.getWhsId() == null ? "" :m.getWhsId())
                        .location(m.getLocation() == null ? "" : m.getLocation())
                        .whsNm(m.getWhsNm() == null ? "" : m.getWhsNm() + " - " + m.getLocationNm())
                        .dlvReqDt(m.getDlvReqDt() == null ? "" : m.getDlvReqDt())
                        .dlvSchDt(m.getDlvSchDt() == null ? "" : m.getDlvSchDt())
                        .dlvMgrNm(m.getDlvMgrNm() == null ? "" : m.getDlvMgrNm())
                        .dlvMgrTelNo(m.getDlvMgrTelNo() == null ? "" : m.getDlvMgrTelNo())
                        .pchPodrUnqNo(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getPchPodrUnqNo() == null ? "" : m.getDeliDtlMgntInfo().getPchPodrUnqNo())
                        .pchPodrDtlNo(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getPchPodrDtlNo() == null ? "" : m.getDeliDtlMgntInfo().getPchPodrDtlNo())
                        .pchReqUnqNo(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getPchReqUnqNo() == null ? "" : m.getDeliDtlMgntInfo().getPchReqUnqNo())
                        .pchReqDltNo(m.getDeliDtlMgntInfo() == null ? "" : m.getDeliDtlMgntInfo().getPchReqDtlNo() == null ? "" : m.getDeliDtlMgntInfo().getPchReqDtlNo())
                        .spplyId(m.getSpplyId() == null ? "" : m.getSpplyId())
                        .spplyNm(m.getSpplyNm() == null ? "" : m.getSpplyNm())
                        .build())
                .collect(Collectors.toList());
        return GridResponse.toDTO(gridPage, gridTotal, gridRecords, gridRows);
    }
 */
    /* 입고처리 저장
    @Transactional
    public void saveWarehouseProc(String userId, SaveWarehouseProcRequest saveWarehouseProcRequest) throws Exception {
        try {

            List<WhsProcInfoPtclEntity> gridInsertData = saveWarehouseProcRequest.toCodeEntities(saveWarehouseProcRequest.getGridInsertData());
            List<DeliDtlMgntEntity> serarchList = new ArrayList<DeliDtlMgntEntity>();
            if (gridInsertData.size() > 0) {
                for (int i = 0 ; i < gridInsertData.size() ; i++) {
                    WhsProcInfoPtclEntity whsProcData = gridInsertData.get(i);
                    DeliDtlMgntEntity deliData = new DeliDtlMgntEntity();
                    deliData.setDlvSttmtDtlNo(whsProcData.getDlvSttmtUnqNo() + whsProcData.getDlvSttmtDtlNo());
                    serarchList.add(deliData);
                }

                List<DeliInfoMgntEntity> targetList  =   shmtOdrMapper.selectWarehouseProcList(saveWarehouseProcRequest.getBrandId(), saveWarehouseProcRequest.getWhsId(), serarchList);

                List<WhsProcInfoPtclEntity> gridUpdateData = new ArrayList<WhsProcInfoPtclEntity>();
                List<StckMgntBaseInfoEntity> wareGridUpdateData = new ArrayList<StckMgntBaseInfoEntity>();
                List<DeliDtlMgntEntity> deliDtlGridUpdateData = new ArrayList<DeliDtlMgntEntity>();
                List<ShmtOdrDtlEntity> shmtDtlGridUpdateData = new ArrayList<ShmtOdrDtlEntity>();
                List<PchOdrDtlPtclEntity> PchOdrDtlGridUpdateData = new ArrayList<PchOdrDtlPtclEntity>();


                // loan_mgnt_unq_no 매장납품일 경우
                //selectStoreLoanMgntUnqNo
                String loanMgntUnqNo = "";
                long loanAmt = 0 ; // 여신차감할 금액 (사용금액 - 여신차감금액,   잔액금액 - 여신차감금액)
                if (!"".equals(saveWarehouseProcRequest.getStoreId())) {
                    loanMgntUnqNo = storeBaseInfoMapper.selectStoreLoanMgntUnqNo(saveWarehouseProcRequest.getStoreId());
                }

                // 우선 입고수량과 납품수량 비교를 처리함
                for (int i = 0 ; i < gridInsertData.size() ; i++) {
                    WhsProcInfoPtclEntity whsProcData = gridInsertData.get(i);

                    for (int j = 0  ; j < targetList.size() ; j++) {
                        DeliInfoMgntEntity targetData = targetList.get(j);
                        //System.out.println("=whsProcData=======getDlvSttmtUnqNo============>" + i + "==" + j + "==>" + whsProcData.getDlvSttmtUnqNo() +  "==" +  targetData.getDlvSttmtUnqNo());
                       // System.out.println("=whsProcData=======getDlvSttmtDtlNo============>" + i + "==" + j + "==>"  + whsProcData.getDlvSttmtDtlNo() +  "==" +   targetData.getDeliDtlMgntInfo().getDlvSttmtDtlNo());
                        if (whsProcData.getDlvSttmtUnqNo().equals(targetData.getDlvSttmtUnqNo()) && whsProcData.getDlvSttmtDtlNo().equals(targetData.getDeliDtlMgntInfo().getDlvSttmtDtlNo())) {

                            if (whsProcData.getWhsQty() > targetData.getDeliDtlMgntInfo().getDlvQty()) {
                                 // 오류 처리
                                throw new GlobalException(SystemMessageCode.ERR_NOTWAREHOUSE);
                            }

                            // 입고번호 생성
                            whsProcData.setWhsMgntUnqNo(fnGetDealNo(17,""));

                            //System.out.println("=whsProcData=======setWhsMgntUnqNo============>" + i + "==" + j + "==>"  + whsProcData.getWhsMgntUnqNo());

                            whsProcData.setDlvSttmtDtlNo(targetData.getDeliDtlMgntInfo().getDlvSttmtDtlNo());
                            whsProcData.setDlvSttmtUnqNo(targetData.getDlvSttmtUnqNo());
                            whsProcData.setBrandId(targetData.getBrandId());
                            whsProcData.setStoreId(targetData.getStoreId());
                            whsProcData.setWhsId(targetData.getWhsId());
                            whsProcData.setLocation(targetData.getLocation());
                            whsProcData.setSpplyId(targetData.getSpplyId());
                            whsProcData.setSpplyNm(targetData.getSpplyNm());
                            whsProcData.setWhsDvsn(targetData.getWhsDvsn());
                            whsProcData.setPodrQty(targetData.getDeliDtlMgntInfo().getPodrQty());
                            whsProcData.setDlvQty(targetData.getDeliDtlMgntInfo().getDlvQty());
                            whsProcData.setUnit(targetData.getDeliDtlMgntInfo().getUnit());
                            whsProcData.setUnitAmt(targetData.getDeliDtlMgntInfo().getUnitAmt());
                            whsProcData.setDlvReqDt(targetData.getDlvReqDt());
                            whsProcData.setDlvSchDt(targetData.getDlvSchDt());
                            whsProcData.setWhsCnfmNm(userId);
                            whsProcData.setDlvMgrNm(targetData.getDlvMgrNm());
                            whsProcData.setDlvMgrTelNo(targetData.getDlvMgrTelNo());
                            whsProcData.setDlvMgrEmal(targetData.getDlvMgrEmal());
                            whsProcData.setDlvMgrMblNo(targetData.getDlvMgrMblNo());
                            whsProcData.setItemId(targetData.getDeliDtlMgntInfo().getItemId());
                            whsProcData.setItemNm(targetData.getDeliDtlMgntInfo().getItemNm());
                            whsProcData.setWhsAmt(Long.valueOf(targetData.getDeliDtlMgntInfo().getUnitAmt() * whsProcData.getWhsQty()));
                            whsProcData.setWhsDlvChrg(null);
                            //whsProcData.setDlvMgrId(targetData.getdlvmgr);
                            whsProcData.setDlvCnfmDocFileNo(whsProcData.getDlvCnfmDocFileNo());
                            whsProcData.setSttlYn("N");
                            whsProcData.setPchPodrUnqNo(targetData.getDeliDtlMgntInfo().getPchPodrUnqNo());
                            whsProcData.setPchPodrDtlNo(targetData.getDeliDtlMgntInfo().getPchPodrDtlNo());
                            whsProcData.setPchReqUnqNo(targetData.getDeliDtlMgntInfo().getPchReqUnqNo());
                            whsProcData.setPchReqDtlNo(targetData.getDeliDtlMgntInfo().getPchReqDtlNo());
                            whsProcData.setShmtReqUnqNo(targetData.getDeliDtlMgntInfo().getShmtReqUnqNo());
                            whsProcData.setShmtReqDtlNo(targetData.getDeliDtlMgntInfo().getShmtReqDtlNo());

                            gridUpdateData.add(whsProcData);

                            // 정산할때 함 여신관련한 여신차감할 입고금액 세팅
                            //loanAmt = loanAmt + (targetData.getDeliDtlMgntInfo().getUnitAmt() * whsProcData.getWhsQty());

                            // 재고처리를 위한 작업업
                            StckMgntBaseInfoEntity smbaseInfoEntity = new StckMgntBaseInfoEntity();
                            smbaseInfoEntity.setBrandId(saveWarehouseProcRequest.getBrandId());
                            smbaseInfoEntity.setWhsId(saveWarehouseProcRequest.getWhsId());
                            smbaseInfoEntity.setLocation(whsProcData.getLocation());
                            smbaseInfoEntity.setItemId(whsProcData.getItemId());
                            smbaseInfoEntity.setStckQty(whsProcData.getWhsQty());
                            wareGridUpdateData.add(smbaseInfoEntity);

                            // 납품서 상태 정의  dlvSttmtUnqNo  dlvDtlStCd
                            DeliDtlMgntEntity deliDtlEntity = new DeliDtlMgntEntity();
                            deliDtlEntity.setDlvSttmtUnqNo(whsProcData.getDlvSttmtUnqNo());
                            deliDtlEntity.setDlvSttmtDtlNo(whsProcData.getDlvSttmtDtlNo());
                            if (whsProcData.getWhsQty() > 0 ) {
                                deliDtlEntity.setDlvDtlStCd("DLD1");
                            } else {
                                deliDtlEntity.setDlvDtlStCd("DLD3");
                            }
                            deliDtlGridUpdateData.add(deliDtlEntity);


                            // 출하지시 상태정의
                            if (!"".equals(whsProcData.getShmtReqUnqNo()) && whsProcData.getShmtReqUnqNo() != null) {
                                ShmtOdrDtlEntity shmtDtlData = new ShmtOdrDtlEntity();
                                shmtDtlData.setShmtReqUnqNo(whsProcData.getShmtReqUnqNo());
                                shmtDtlData.setShmtReqDtlNo(whsProcData.getPchReqDtlNo());
                                if (whsProcData.getWhsQty() > 0 ) {
                                    shmtDtlData.setShmtDtlStCd("SHMD2");
                                } else {
                                    shmtDtlData.setShmtDtlStCd("SHMD3");
                                }

                                shmtDtlGridUpdateData.add(shmtDtlData);
                            }

                            PchOdrDtlPtclEntity pchOdrDtlData = new PchOdrDtlPtclEntity();
                            pchOdrDtlData.setPchPodrUnqNo(whsProcData.getPchPodrUnqNo());
                            pchOdrDtlData.setPchPodrDtlNo(whsProcData.getPchPodrDtlNo());
                            if (whsProcData.getWhsQty() > 0 ) {
                                pchOdrDtlData.setPodrDtlStCd("POD4");
                            } else {
                                pchOdrDtlData.setPodrDtlStCd("POD2");

                                if (!"".equals(loanMgntUnqNo)) {
                                    loanAmt = loanAmt + ( targetData.getDeliDtlMgntInfo().getDlvQty() * targetData.getDeliDtlMgntInfo().getUnitAmt() ) ;
                                }
                            }

                            PchOdrDtlGridUpdateData.add(pchOdrDtlData);
                            break;
                        }


                    }  // or문 종료
                }

                    // 입고데이타 저장
                    shmtOdrMapper.insertWhsProcInfoPtcl(userId, gridUpdateData);

                    // 재고관련 정리 필요
                    stockMngMapper.updateWarehouseStockQty(userId, wareGridUpdateData);

                    // 납품서 상세 처리
                    shmtOdrMapper.updateDeliDtlStCd(userId, deliDtlGridUpdateData);

                    // 납품서 헤더 상태 처리
                    List<DeliInfoMgntEntity> deliInfoStList = shmtOdrMapper.selectDeliInfoStList(userId, deliDtlGridUpdateData);
                    shmtOdrMapper.updateDeliInfoStCd(userId, deliInfoStList);

                    // 출하지시서 상태 업데이트
                    if (shmtDtlGridUpdateData.size() > 0) {
                        shmtOdrMapper.updateShmtDtlStCd(userId,shmtDtlGridUpdateData );
                        List<ShmtOdrBaseEntity> shmtInfoStList = shmtOdrMapper.selectShmtInfoStList(userId, shmtDtlGridUpdateData);
                        shmtOdrMapper.updateShmtInfoStCd(userId, shmtInfoStList);
                    }


                    shmtOdrMapper.updatePchPodrDtlStCd(userId, PchOdrDtlGridUpdateData);

                    String pchPodrUnqNo = "";
                    for (int k = 0; k < PchOdrDtlGridUpdateData.size(); k++) {
                        if (!pchPodrUnqNo.equals(PchOdrDtlGridUpdateData.get(k).getPchPodrUnqNo())) {
                            pchPodrUnqNo = PchOdrDtlGridUpdateData.get(k).getPchPodrUnqNo();
                            String pchOdrStCd = pchOrdService.selectOdrDtlStatusList(pchPodrUnqNo);
                            pchOrdMapper.updateChgPodrStCd(userId, pchOdrStCd, pchPodrUnqNo);
                        }
                    }

                    // 발주 헤더가 취소면 해당 발주건에 대한 사용금액을 원복 처리한다.
                    if (!"".equals(loanMgntUnqNo) && loanAmt > 0) {
                        // 여신관련 정리 필요 loanAmt 업데이트
                        loanStateMapper.updateloanMinusInstProc(loanMgntUnqNo, saveWarehouseProcRequest.getStoreId(), loanAmt);
                    }



            }

        } catch (GlobalException e) {
            //e.getStackTrace();
            e.printStackTrace();
            throw new GlobalException(e.getSystemMessageCode());
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
*/

    /*
      입고 현황 그리드 리스트 조회  @Param("sBrandId") String sBrandId, @Param("sStoreId") String sStoreId,
      @Param("fromDt") String fromDt, @Param("toDt") String toDt, @Param("sPchPodrUnqNo") String sPchPodrUnqNo, @Param("sSpplyId") String sSpplyId, @Param("sWhsId") String sWhsId, @Param("sItemNm") String sItemNm

    public GridResponse selectWarehouseGridList(String sBrandId, String sStoreId,  String fromDt, String toDt, String sPchPodrUnqNo, String sSpplyId, String sWhsId, String sItemNm, GridRequest gridRequest) throws Exception {
        int gridPage = gridRequest.getGridPage();
        int gridSize = gridRequest.getGridSize();

        fromDt = fromDt == null ? null : fromDt.replace(".", "");
        toDt = toDt == null ? null : toDt.replace(".", "");

        int gridRecords = shmtOdrMapper.selectWarehouseCnt(sBrandId, sStoreId, fromDt, toDt, sPchPodrUnqNo, sSpplyId, sWhsId, sItemNm);
        int gridTotal = fnCalculateGridTotal(gridSize, gridRecords);
        List<WhsProcInfoPtclEntity> entities = shmtOdrMapper.selectWarehouseList(sBrandId, sStoreId, fromDt, toDt, sPchPodrUnqNo, sSpplyId, sWhsId, sItemNm, gridRequest);
        List<Object> gridRows = entities.stream()
                .map(m -> WarehouseSearchGridListResponse.builder()
                        .viewCd("R")
                        .pchPodrUnqNo(m.getPchPodrUnqNo() == null ? "" : m.getPchPodrUnqNo())
                        .pchPodrDtlNo(m.getPchPodrDtlNo() == null ? "" : m.getPchPodrDtlNo())
                        .dlvSttmtUnqNo(m.getDlvSttmtUnqNo() == null ? "" : m.getDlvSttmtUnqNo())
                        .dlvSttmtDtlNo(m.getDlvSttmtDtlNo() == null ? "" : m.getDlvSttmtDtlNo() )
                        .podrQty(m.getPodrQty() == null ? 0 : m.getPodrQty())
                        .dlvQty(m.getDlvQty() == null ? 0 : m.getDlvQty())
                        .whsQty(m.getWhsQty() == null ? 0 : m.getWhsQty())
                        .dlvReqDt(m.getDlvReqDt() == null ? "" : m.getDlvReqDt())
                        .dlvSchDt(m.getDlvSchDt() == null ? "" : m.getDlvSchDt())
                        .dlvCmpltDt(m.getDlvCmpltDt() == null ? "" : m.getDlvCmpltDt())
                        .whsCnfmNm(m.getWhsCnfmNm() == null ? "" : m.getWhsCnfmNm())
                        .dlvMgrNm(m.getDlvMgrNm() == null ? "" : m.getDlvMgrNm())
                        .dlvMgrTelNo(m.getDlvMgrTelNo() == null ? "" : m.getDlvMgrTelNo())
                        .itemId(m.getItemId() == null ? "" : m.getItemId())
                        .itemNm(m.getItemNm() == null ? "" : m.getItemNm())
                        .unit(m.getUnit() == null ? "" : m.getUnit())
                        .whsAmt(m.getWhsAmt() == null ? 0 : m.getWhsAmt())
                        .build())
                .collect(Collectors.toList());
        return GridResponse.toDTO(gridPage, gridTotal, gridRecords, gridRows);
    }

 */

}



